pub enum ParamsError {
InvalidPolynomial(PolynomialError),
ZeroModulusPolynomial,
ConstantModulusPolynomial,
ModulusPolynomialDegreeMismatch {
degree: usize,
max_degree: usize,
},
NonInvertibleModulusPolynomialLead {
coefficient: u64,
modulus: u64,
},
NttLengthOverflow {
max_degree: usize,
},
NttLengthUnsupported {
length: usize,
modulus: u64,
},
InvalidPrimitiveRoot {
primitive_root: u64,
length: usize,
modulus: u64,
},
}Expand description
Errors returned while validating Params.
Variants
InvalidPolynomial(PolynomialError)
Underlying polynomial validation failed.
ZeroModulusPolynomial
Modulus polynomial cannot be zero.
ConstantModulusPolynomial
Modulus polynomial must be non-constant.
ModulusPolynomialDegreeMismatch
degree(f) must match max_degree for a consistent fixed ring shape.
NonInvertibleModulusPolynomialLead
Leading coefficient of f(x) must be invertible in Z_q.
NttLengthOverflow
Derived transform size overflowed for the selected degree bound.
NttLengthUnsupported
Derived NTT length is unsupported by the modulus (length must divide q - 1).
InvalidPrimitiveRoot
Primitive root does not induce a valid root of unity for the derived NTT length.